==> xlniuxdata_newGift-1.0.14-sources.jar: com/xunlei/niux/data/newGift/dao/GiftDaoImpl.java <==
package com.xunlei.niux.data.newGift.dao;

import com.ferret.common.dao.BaseDaoImpl;
import com.ferret.common.dao.enums.OrderType;
import com.ferret.common.dao.vo.Page;
import com.xunlei.niux.data.newGift.vo.Gift;
import com.xunlei.niux.data.newGift.vo.GiftAct;
import com.xunlei.niux.data.newGift.vo.GiftResource;
import org.apache.commons.lang.StringUtils;
import org.springframework.jdbc.core.RowCallbackHandler;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.*;

/**
 * Created by zy on 2016/3/30.
 */
public class GiftDaoImpl extends BaseDaoImpl implements GiftDao {
    @Override
    public List<Gift> getGiftsByLogin(Gift gift, Page page, String login) {
        GiftAct act = new GiftAct();
        act.setActStaff(login);
        act.setStatus(1);
        Page page1 = new Page();
        page1.addOrder("isAdmin", OrderType.DESC);
        List<GiftAct> byObject = findByObject(GiftAct.class, act,page1 );
        if(byObject==null||byObject.size()==0){
            return null;
        }

        if(byObject.get(0).getIsAdmin()==1){
            return findByObject(Gift.class,gift,page);
        }

        String actNos = "";
        for(GiftAct act1 : byObject){
            actNos += "'"+act1.getActNo()+"',";
        }

        actNos = actNos.substring(0,actNos.length()-1);
        List<Object> list = new ArrayList<Object>();

        String sql = "select * from gift where 1=1 ";

        sql += getConditon(gift,list,actNos);

        sql += " order by editTime desc ";

        if(page.getPageNo()<=0){
            page.setPageNo(1);
        }

        sql += " limit "+((page.getPageNo()-1)*page.getPageSize()) +", "+page.getPageSize();

        List<Gift> gifts = findBySql(Gift.class, sql, list);

        return gifts;
    }

    private String getConditon(Gift gift,List<Object> list,String actNos){
        String sql = "";

        if(gift.getSeqId()!=null&&gift.getSeqId()>0){
            sql += " and seqId = ? ";
            list.add(gift.getSeqId());

        }

        if(StringUtils.isNotEmpty(gift.getActNo())){
            sql += " and actNo = ? ";
            list.add(gift.getActNo());
        }

        if(StringUtils.isNotEmpty(gift.getGiftName())){
            sql += " and giftName = ? ";
            list.add(gift.getGiftName());
        }

        if(gift.getModelNo()!=null&&gift.getModelNo()>0){
            sql += " and modelNo = ? ";
            list.add(gift.getModelNo());
        }

        if(StringUtils.isNotEmpty(gift.getAdvNo())){
            sql += " and advNo = ? ";
            list.add(gift.getAdvNo());
        }

        if(actNos.length()>1){
            sql += " and actNo in ("+ actNos+") ";
        }
        return sql;
    }

    @Override
    public int countGiftsByLogin(Gift gift, String login) {
        GiftAct act = new GiftAct();
        act.setActStaff(login);
        act.setStatus(1);
        Page page1 = new Page();
        page1.addOrder("isAdmin", OrderType.DESC);
        List<GiftAct> byObject = findByObject(GiftAct.class, act,page1 );
        if(byObject==null||byObject.size()==0){
            return 0;
        }

        if(byObject.get(0).getIsAdmin()==1){
            return count(gift);
        }

        String actNos = "";
        for(GiftAct act1 : byObject){
            actNos += "'"+act1.getActNo()+"',";
        }
        actNos = actNos.substring(0,actNos.length()-1);
        List<Object> list =  new ArrayList<Object>();
        String sql = "select count(*) from gift where 1=1 " + getConditon(gift,list,actNos);
        return getJdbcTemplate().queryForInt(sql, list.toArray());
    }

    @Override
    public Map<String, Object> getGiftMap(String actNo, int modelNo) {
        String sql ="select * from gift\n" +
                "LEFT JOIN giftextinfo on gift.seqid = giftextinfo.giftId\n" +
                "where actNo=? and modelNo=? and gift.status = ?\n" +
                "ORDER BY gift.seqId DESC ,giftextinfo.type ,giftextinfo.seqId DESC";
        final Map<String,Object> map = new HashMap<String, Object>();
        getJdbcTemplate().query(sql, new Object[]{actNo,modelNo,1}, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet rs) throws SQLException {
                if(!map.containsKey("giftId")){
                    map.put("giftId",rs.getString("seqId"));
                    map.put("giftName",rs.getString("giftname"));
                    map.put("modelNo",rs.getString("modelNo"));
                    map.put("advNo",rs.getString("advNo"));
                    map.put("startTime",rs.getString("startTime"));
                    map.put("endTime",rs.getString("endTime"));
                    map.put("total",rs.getString("total"));
                    map.put("leftNm",rs.getString("leftNm"));
                    map.put("orderNo",rs.getString("orderNo"));
                    map.put("extInfo",new ArrayList<Map<String,Object>>());
                }
                Map<String,Object> extInfoMap = new HashMap<String, Object>();
                extInfoMap.put("type",rs.getString("type"));
                extInfoMap.put("keyCode",rs.getString("keyCode"));
                extInfoMap.put("keyValue",rs.getString("keyValue"));
                ((List)map.get("extInfo")).add(extInfoMap);
            }
        });
        return map;
    }

    @Override
    public Gift getGiftByLock(long id) {
        String sql = "select * from gift where seqId = ?  for update";
        List<Object> param = new ArrayList<Object>();
        param.add(id);
        List<Gift> bySql = this.findBySql(Gift.class, sql, param);
        return (bySql==null||bySql.size()==0)?null:bySql.get(0);
    }

    @Override
    public List<Map<String, Object>> getExtGifts(String actNo, int size) {
        String sql ="SELECT gtmp.seqId, gtmp.giftName,gtmp.modelNo,gtmp.orderNo,gei.type,gei.keyCode,gei.keyValue," +
                "gei.status,gtmp.startTime,gtmp.endTime,gtmp.total,gtmp.leftNm,gtmp.advNo,gtmp.actNo,gtmp.bonusType,gtmp.bonus from \n" +
                "(SELECT gift.seqId, gift.giftName,gift.modelNo,gift.orderNo,gift.advNo,gift.actNo,gift.bonusType,gift.bonus, " +
                "gift.startTime,gift.endTime,gift.total,gift.leftNm FROM gift  INNER JOIN \n" +
                "                (SELECT  max(orderNo) as orderNo,modelNo,actNo  from gift  where actNo= ? and status =1 \n" +
                "                 and startTime < NOW() and endTime > NOW() group by modelNo order by modelNo ) g  \n" +
                "                on gift.actNo = g.actNo and gift.modelNo = g.modelNo and gift.orderNo = g.OrderNo limit ? ) gtmp \n" +
                "left join giftextinfo gei on gtmp.seqid = gei.giftid AND gei.status =1  order by gtmp.modelNo ,gtmp.orderNo,gei.seqid   ";

        final List<Map<String,Object>> list = new ArrayList<Map<String, Object>>();
        getJdbcTemplate().query(sql, new Object[]{actNo,size}, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet rs) throws SQLException {
                Long seqid = rs.getLong("seqId");
                Map<String,Object> map = list.size()==0?null:list.get(list.size()-1);
                Long mapSeqId = map==null||map.get("seqId")==null?0:(Long) map.get("seqId");
                if(mapSeqId!=seqid){
                    map = new HashMap<String, Object>();
                    list.add(map);
                    map.put("seqId",rs.getLong("seqId"));
                    map.put("giftName",rs.getString("giftName"));
                    map.put("giftId",rs.getString("seqId"));
                    map.put("actNo",rs.getString("actNo"));
                    map.put("modelNo",rs.getString("modelNo"));
                    map.put("advNo",rs.getString("advNo"));
                    map.put("startTime",rs.getString("startTime"));
                    map.put("endTime",rs.getString("endTime"));
                    map.put("total",rs.getString("total"));
                    map.put("leftNm",rs.getString("leftNm"));
                    map.put("orderNo",rs.getString("orderNo"));
                    map.put("bonusType",rs.getString("bonusType"));
                    map.put("bonus",rs.getString("bonus"));
                    map.put("extInfo",new ArrayList<Map<String,Object>>());
                }
                if(StringUtils.isNotEmpty(rs.getString("type"))){
                    Map<String,Object> extInfoMap = new HashMap<String, Object>();
                    extInfoMap.put("type",rs.getString("type"));
                    extInfoMap.put("keyCode",rs.getString("keyCode"));
                    extInfoMap.put("keyValue",rs.getString("keyValue"));
                    ((List)map.get("extInfo")).add(extInfoMap);
                }

            }
        });
        return list;
    }

    @Override
    public List<Gift> getGiftsByActNo(String actNo,int size) {
        String sql = "select * from gift where actNo=? and `status`=1 and startTime<=NOW() and endTime >= NOW()" +
                " order by orderNo desc limit ? \n";
        List<Object> param = new ArrayList<Object>(2);
        param.add(actNo);
        param.add(size);
        List<Gift> gifts = findBySql(Gift.class, sql, param);


        return gifts;
    }

    public List<Map<String,Object>> getMobileWeekGifts(String actNo,int size){
        String sql = "SELECT gift.seqId, gift.giftName,gift.modelNo,gift.orderNo FROM gift  INNER JOIN \n" +
                "(SELECT  max(orderNo) as orderNo,modelNo,actNo  from gift  where actNo= ? and status =1" +
                " and startTime < NOW() and endTime > NOW() group by modelNo order by modelNo ) g \n" +
                "on gift.actNo = g.actNo and gift.modelNo = g.modelNo and gift.orderNo = g.OrderNo order by modelNo " +
                " LIMIT ? \n";
        final List<Map<String,Object>> list = new ArrayList<Map<String, Object>>();

        this.getJdbcTemplate().query(sql, new Object[]{actNo, size}, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet rs) throws SQLException {
                Map<String,Object> map = new HashMap<String, Object>();
                map.put("giftId",rs.getLong("seqId"));
                map.put("giftName",rs.getString("giftname"));
                map.put("orderNo",rs.getInt("orderNo"));
                map.put("modelNo",rs.getInt("modelNo"));
                list.add(map);
            }
        });
        return list;
    }

    @Override
    public List<Map<String, Object>> getExtMapGifts(String actNo, int size) {
        String sql ="SELECT gtmp.seqId, gtmp.giftName,gtmp.modelNo,gtmp.orderNo,gei.type,gei.keyCode,gei.keyValue," +
                "gei.status,gtmp.startTime,gtmp.endTime,gtmp.total,gtmp.leftNm,gtmp.advNo,gtmp.actNo,gtmp.bonusType,gtmp.bonus from \n" +
                "(SELECT gift.seqId, gift.giftName,gift.modelNo,gift.orderNo,gift.advNo,gift.actNo,gift.bonusType,gift.bonus, " +
                "gift.startTime,gift.endTime,gift.total,gift.leftNm FROM gift  INNER JOIN \n" +
                "                (SELECT  max(orderNo) as orderNo,modelNo,actNo  from gift  where actNo= ? and status =1 \n" +
                "                 and startTime < NOW() and endTime > NOW() group by modelNo order by modelNo ) g  \n" +
                "                on gift.actNo = g.actNo and gift.modelNo = g.modelNo and gift.orderNo = g.OrderNo limit ? ) gtmp \n" +
                "left join giftextinfo gei on gtmp.seqid = gei.giftid AND gei.status =1  order by gtmp.modelNo ,gtmp.orderNo,gei.seqid   ";

        final List<Map<String,Object>> list = new ArrayList<Map<String, Object>>();
        getJdbcTemplate().query(sql, new Object[]{actNo,size}, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet rs) throws SQLException {
                Long seqid = rs.getLong("seqId");
                Map<String,Object> map = list.size()==0?null:list.get(list.size()-1);
                Long mapSeqId = map==null||map.get("seqId")==null?0:(Long) map.get("seqId");
                if(mapSeqId!=seqid){
                    map = new HashMap<String, Object>();
                    list.add(map);
                    map.put("seqId",rs.getLong("seqId"));
                    map.put("giftName",rs.getString("giftName"));
                    map.put("giftId",rs.getString("seqId"));
                    map.put("actNo",rs.getString("actNo"));
                    map.put("modelNo",rs.getString("modelNo"));
                    map.put("advNo",rs.getString("advNo"));
                    map.put("startTime",rs.getString("startTime"));
                    map.put("endTime",rs.getString("endTime"));
                    map.put("total",rs.getString("total"));
                    map.put("leftNm",rs.getString("leftNm"));
                    map.put("orderNo",rs.getString("orderNo"));
                    map.put("bonusType",rs.getString("bonusType"));
                    map.put("bonus",rs.getString("bonus"));
                }
                if(StringUtils.isNotEmpty(rs.getString("type"))){
                    map.put(rs.getString("type").trim()+"_"+rs.getString("keyCode").trim(),rs.getString("keyValue").trim());
                }
            }
        });
        return list;
    }

    @Override
    public Map<String, Object> getGiftInfoMap(Long giftId) {
        String sql ="select * from gift\n" +
                "LEFT JOIN giftextinfo on gift.seqid = giftextinfo.giftId\n" +
                "where gift.seqId= ?  and gift.status = ?\n" +
                "ORDER BY gift.seqId DESC ,giftextinfo.type ,giftextinfo.seqId DESC";
        final Map<String,Object> map = new HashMap<String, Object>();
        getJdbcTemplate().query(sql, new Object[]{giftId,1}, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet rs) throws SQLException {
                if(!map.containsKey("giftId")){
                    map.put("giftId",rs.getString("seqId"));
                    map.put("modelNo",rs.getString("modelNo"));
                    map.put("giftName",rs.getString("giftname"));
                    map.put("advNo",rs.getString("advNo"));
                    map.put("startTime",rs.getString("startTime"));
                    map.put("endTime",rs.getString("endTime"));
                    map.put("total",rs.getString("total"));
                    map.put("leftNm",rs.getString("leftNm"));
                    map.put("orderNo",rs.getString("orderNo"));
                    map.put("seqId",rs.getLong("seqId"));
                    map.put("actNo",rs.getString("actNo"));
                    map.put("bonus",rs.getString("bonus"));
                    map.put("bonusType",rs.getString("bonusType"));
                }
                if(StringUtils.isNotEmpty(rs.getString("type"))){
                    map.put(rs.getString("type").trim()+"_"+rs.getString("keyCode").trim(),rs.getString("keyValue").trim());
                }
            }
        });
        return map;
    }
}

==> xlniuxdata_newGift-1.0.16-sources.jar: com/xunlei/niux/data/newGift/dao/GiftDaoImpl.java <==
package com.xunlei.niux.data.newGift.dao;

import com.ferret.common.dao.BaseDaoImpl;
import com.ferret.common.dao.enums.OrderType;
import com.ferret.common.dao.vo.Page;
import com.xunlei.niux.data.newGift.vo.Gift;
import com.xunlei.niux.data.newGift.vo.GiftAct;
import com.xunlei.niux.data.newGift.vo.GiftResource;
import org.apache.commons.lang.StringUtils;
import org.springframework.jdbc.core.RowCallbackHandler;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.*;

/**
 * Created by zy on 2016/3/30.
 */
public class GiftDaoImpl extends BaseDaoImpl implements GiftDao {
    @Override
    public List<Gift> getGiftsByLogin(Gift gift, Page page, String login) {
        GiftAct act = new GiftAct();
        act.setActStaff(login);
        act.setStatus(1);
        Page page1 = new Page();
        page1.addOrder("isAdmin", OrderType.DESC);
        List<GiftAct> byObject = findByObject(GiftAct.class, act,page1 );
        if(byObject==null||byObject.size()==0){
            return null;
        }

        if(byObject.get(0).getIsAdmin()==1){
            return findByObject(Gift.class,gift,page);
        }

        String actNos = "";
        for(GiftAct act1 : byObject){
            actNos += "'"+act1.getActNo()+"',";
        }

        actNos = actNos.substring(0,actNos.length()-1);
        List<Object> list = new ArrayList<Object>();

        String sql = "select * from gift where 1=1 ";

        sql += getConditon(gift,list,actNos);

        sql += " order by editTime desc ";

        if(page.getPageNo()<=0){
            page.setPageNo(1);
        }

        sql += " limit "+((page.getPageNo()-1)*page.getPageSize()) +", "+page.getPageSize();

        List<Gift> gifts = findBySql(Gift.class, sql, list);

        return gifts;
    }

    private String getConditon(Gift gift,List<Object> list,String actNos){
        String sql = "";

        if(gift.getSeqId()!=null&&gift.getSeqId()>0){
            sql += " and seqId = ? ";
            list.add(gift.getSeqId());

        }

        if(StringUtils.isNotEmpty(gift.getActNo())){
            sql += " and actNo = ? ";
            list.add(gift.getActNo());
        }

        if(StringUtils.isNotEmpty(gift.getGiftName())){
            sql += " and giftName = ? ";
            list.add(gift.getGiftName());
        }

        if(gift.getModelNo()!=null&&gift.getModelNo()>0){
            sql += " and modelNo = ? ";
            list.add(gift.getModelNo());
        }

        if(StringUtils.isNotEmpty(gift.getAdvNo())){
            sql += " and advNo = ? ";
            list.add(gift.getAdvNo());
        }

        if(actNos.length()>1){
            sql += " and actNo in ("+ actNos+") ";
        }
        return sql;
    }

    @Override
    public int countGiftsByLogin(Gift gift, String login) {
        GiftAct act = new GiftAct();
        act.setActStaff(login);
        act.setStatus(1);
        Page page1 = new Page();
        page1.addOrder("isAdmin", OrderType.DESC);
        List<GiftAct> byObject = findByObject(GiftAct.class, act,page1 );
        if(byObject==null||byObject.size()==0){
            return 0;
        }

        if(byObject.get(0).getIsAdmin()==1){
            return count(gift);
        }

        String actNos = "";
        for(GiftAct act1 : byObject){
            actNos += "'"+act1.getActNo()+"',";
        }
        actNos = actNos.substring(0,actNos.length()-1);
        List<Object> list =  new ArrayList<Object>();
        String sql = "select count(*) from gift where 1=1 " + getConditon(gift,list,actNos);
        return getJdbcTemplate().queryForInt(sql, list.toArray());
    }

    @Override
    public Map<String, Object> getGiftMap(String actNo, int modelNo) {
        String sql ="select * from gift\n" +
                "LEFT JOIN giftextinfo on gift.seqid = giftextinfo.giftId\n" +
                "where actNo=? and modelNo=? and gift.status = ?\n" +
                "ORDER BY gift.seqId DESC ,giftextinfo.type ,giftextinfo.seqId DESC";
        final Map<String,Object> map = new HashMap<String, Object>();
        getJdbcTemplate().query(sql, new Object[]{actNo,modelNo,1}, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet rs) throws SQLException {
                if(!map.containsKey("giftId")){
                    map.put("giftId",rs.getString("seqId"));
                    map.put("giftName",rs.getString("giftname"));
                    map.put("modelNo",rs.getString("modelNo"));
                    map.put("advNo",rs.getString("advNo"));
                    map.put("startTime",rs.getString("startTime"));
                    map.put("endTime",rs.getString("endTime"));
                    map.put("total",rs.getString("total"));
                    map.put("leftNm",rs.getString("leftNm"));
                    map.put("orderNo",rs.getString("orderNo"));
                    map.put("extInfo",new ArrayList<Map<String,Object>>());
                }
                Map<String,Object> extInfoMap = new HashMap<String, Object>();
                extInfoMap.put("type",rs.getString("type"));
                extInfoMap.put("keyCode",rs.getString("keyCode"));
                extInfoMap.put("keyValue",rs.getString("keyValue"));
                ((List)map.get("extInfo")).add(extInfoMap);
            }
        });
        return map;
    }

    @Override
    public Gift getGiftByLock(long id) {
        String sql = "select * from gift where seqId = ?  for update";
        List<Object> param = new ArrayList<Object>();
        param.add(id);
        List<Gift> bySql = this.findBySql(Gift.class, sql, param);
        return (bySql==null||bySql.size()==0)?null:bySql.get(0);
    }

    @Override
    public List<Map<String, Object>> getExtGifts(String actNo, int size) {
        String sql ="SELECT gtmp.seqId, gtmp.giftName,gtmp.modelNo,gtmp.orderNo,gei.type,gei.keyCode,gei.keyValue," +
                "gei.status,gtmp.startTime,gtmp.endTime,gtmp.total,gtmp.leftNm,gtmp.advNo,gtmp.actNo,gtmp.bonusType,gtmp.bonus from \n" +
                "(SELECT gift.seqId, gift.giftName,gift.modelNo,gift.orderNo,gift.advNo,gift.actNo,gift.bonusType,gift.bonus, " +
                "gift.startTime,gift.endTime,gift.total,gift.leftNm FROM gift  INNER JOIN \n" +
                "                (SELECT  max(orderNo) as orderNo,modelNo,actNo  from gift  where actNo= ? and status =1 \n" +
                "                 and startTime < NOW() and endTime > NOW() group by modelNo order by modelNo ) g  \n" +
                "                on gift.actNo = g.actNo and gift.modelNo = g.modelNo and gift.orderNo = g.OrderNo limit ? ) gtmp \n" +
                "left join giftextinfo gei on gtmp.seqid = gei.giftid AND gei.status =1  order by gtmp.modelNo ,gtmp.orderNo,gei.seqid   ";

        final List<Map<String,Object>> list = new ArrayList<Map<String, Object>>();
        getJdbcTemplate().query(sql, new Object[]{actNo,size}, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet rs) throws SQLException {
                Long seqid = rs.getLong("seqId");
                Map<String,Object> map = list.size()==0?null:list.get(list.size()-1);
                Long mapSeqId = map==null||map.get("seqId")==null?0:(Long) map.get("seqId");
                if(mapSeqId!=seqid){
                    map = new HashMap<String, Object>();
                    list.add(map);
                    map.put("seqId",rs.getLong("seqId"));
                    map.put("giftName",rs.getString("giftName"));
                    map.put("giftId",rs.getString("seqId"));
                    map.put("actNo",rs.getString("actNo"));
                    map.put("modelNo",rs.getString("modelNo"));
                    map.put("advNo",rs.getString("advNo"));
                    map.put("startTime",rs.getString("startTime"));
                    map.put("endTime",rs.getString("endTime"));
                    map.put("total",rs.getString("total"));
                    map.put("leftNm",rs.getString("leftNm"));
                    map.put("orderNo",rs.getString("orderNo"));
                    map.put("bonusType",rs.getString("bonusType"));
                    map.put("bonus",rs.getString("bonus"));
                    map.put("extInfo",new ArrayList<Map<String,Object>>());
                }
                if(StringUtils.isNotEmpty(rs.getString("type"))){
                    Map<String,Object> extInfoMap = new HashMap<String, Object>();
                    extInfoMap.put("type",rs.getString("type"));
                    extInfoMap.put("keyCode",rs.getString("keyCode"));
                    extInfoMap.put("keyValue",rs.getString("keyValue"));
                    ((List)map.get("extInfo")).add(extInfoMap);
                }

            }
        });
        return list;
    }

    @Override
    public List<Gift> getGiftsByActNo(String actNo,int size) {
        String sql = "select * from gift where actNo=? and `status`=1 and startTime<=NOW() and endTime >= NOW()" +
                " order by orderNo desc limit ? \n";
        List<Object> param = new ArrayList<Object>(2);
        param.add(actNo);
        param.add(size);
        List<Gift> gifts = findBySql(Gift.class, sql, param);


        return gifts;
    }

    public List<Map<String,Object>> getMobileWeekGifts(String actNo,int size){
        String sql = "SELECT gift.seqId, gift.giftName,gift.modelNo,gift.orderNo FROM gift  INNER JOIN \n" +
                "(SELECT  max(orderNo) as orderNo,modelNo,actNo  from gift  where actNo= ? and status =1" +
                " and startTime < NOW() and endTime > NOW() group by modelNo order by modelNo ) g \n" +
                "on gift.actNo = g.actNo and gift.modelNo = g.modelNo and gift.orderNo = g.OrderNo order by modelNo " +
                " LIMIT ? \n";
        final List<Map<String,Object>> list = new ArrayList<Map<String, Object>>();

        this.getJdbcTemplate().query(sql, new Object[]{actNo, size}, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet rs) throws SQLException {
                Map<String,Object> map = new HashMap<String, Object>();
                map.put("giftId",rs.getLong("seqId"));
                map.put("giftName",rs.getString("giftname"));
                map.put("orderNo",rs.getInt("orderNo"));
                map.put("modelNo",rs.getInt("modelNo"));
                list.add(map);
            }
        });
        return list;
    }

    @Override
    public List<Map<String, Object>> getExtMapGifts(String actNo, int size) {
        String sql ="SELECT gtmp.seqId, gtmp.giftName,gtmp.modelNo,gtmp.orderNo,gei.type,gei.keyCode,gei.keyValue," +
                "gei.status,gtmp.startTime,gtmp.endTime,gtmp.total,gtmp.leftNm,gtmp.advNo,gtmp.actNo,gtmp.bonusType,gtmp.bonus from \n" +
                "(SELECT gift.seqId, gift.giftName,gift.modelNo,gift.orderNo,gift.advNo,gift.actNo,gift.bonusType,gift.bonus, " +
                "gift.startTime,gift.endTime,gift.total,gift.leftNm FROM gift  INNER JOIN \n" +
                "                (SELECT  max(orderNo) as orderNo,modelNo,actNo  from gift  where actNo= ? and status =1 \n" +
                "                 and startTime < NOW() and endTime > NOW() group by modelNo order by modelNo ) g  \n" +
                "                on gift.actNo = g.actNo and gift.modelNo = g.modelNo and gift.orderNo = g.OrderNo limit ? ) gtmp \n" +
                "left join giftextinfo gei on gtmp.seqid = gei.giftid AND gei.status =1  order by gtmp.modelNo ,gtmp.orderNo,gei.seqid   ";

        final List<Map<String,Object>> list = new ArrayList<Map<String, Object>>();
        Object[] params = {actNo, size};
        getList4Map(list,sql,params);
        return list;
    }

    @Override
    public Map<String, Object> getGiftInfoMap(Long giftId) {
        String sql ="select * from gift\n" +
                "LEFT JOIN giftextinfo on gift.seqid = giftextinfo.giftId\n" +
                "where gift.seqId= ?  and gift.status = ?\n" +
                "ORDER BY gift.seqId DESC ,giftextinfo.type ,giftextinfo.seqId DESC";
        final Map<String,Object> map = new HashMap<String, Object>();
        getJdbcTemplate().query(sql, new Object[]{giftId,1}, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet rs) throws SQLException {
                addInfo2Map(map,rs);
            }
        });
        return map;
    }

    private List<Map<String,Object>> getList4Map(final List<Map<String,Object>> list,String sql , Object [] params ){
        getJdbcTemplate().query(sql, params, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet rs) throws SQLException {
                Long seqid = rs.getLong("seqId");
                Map<String,Object> map = list.size()==0?null:list.get(list.size()-1);
                Long mapSeqId = map==null||map.get("seqId")==null?0:(Long) map.get("seqId");
                if(mapSeqId!=seqid){
                    map = new HashMap<String, Object>();
                    list.add(map);
                }
                addInfo2Map(map,rs);
            }
        });
        return list;
    }

    private void addInfo2Map(Map<String,Object> map,ResultSet rs) throws SQLException {
        if(!map.containsKey("giftId")){
            map.put("giftId",rs.getString("seqId"));
            map.put("modelNo",rs.getString("modelNo"));
            map.put("giftName",rs.getString("giftname"));
            map.put("advNo",rs.getString("advNo"));
            map.put("startTime",rs.getString("startTime"));
            map.put("endTime",rs.getString("endTime"));
            map.put("total",rs.getString("total"));
            map.put("leftNm",rs.getString("leftNm"));
            map.put("orderNo",rs.getString("orderNo"));
            map.put("seqId",rs.getLong("seqId"));
            map.put("bonus",rs.getString("bonus"));
            map.put("actNo",rs.getString("actNo"));
            map.put("bonusType",rs.getString("bonusType"));
        }
        if(StringUtils.isNotEmpty(rs.getString("type"))){
            map.put(rs.getString("type").trim()+"_"+rs.getString("keyCode").trim(),rs.getString("keyValue").trim());
        }
    }

    @Override
    public List<Map<String, Object>> getGiftInfoByBath(Long... giftId) {
        if(giftId.length==0){
            return Collections.EMPTY_LIST;
        }
        String sql ="select * from gift\n" +
                " LEFT JOIN giftextinfo on gift.seqid = giftextinfo.giftId\n" +
                " where gift.seqId in ( "+StringUtils.join(giftId, ",")+" ) and gift.status = ?  \n "+
                " ORDER BY gift.seqId DESC ,giftextinfo.type ,giftextinfo.seqId DESC";
        final List<Map<String,Object>> list = new ArrayList<Map<String, Object>>();
        Object[] params = { 1};
        getList4Map(list,sql,params);
        return list;
    }
}
